@@ -7,12 +7,14 @@ from onnx2pytorch.utils import get_selection
 class Squeeze(Operator):
     def __init__(self, dim=None):
         self.dim = dim
-        if dim is not None:
-            self.selection = get_selection(torch.tensor(0), self.dim)
         super().__init__()
 
     def forward(self, input):
         if self.dim is None:
             return torch.squeeze(input)
+        elif isinstance(self.dim, int):
+            return torch.squeeze(input, dim=self.dim)
         else:
-            return input[self.selection]
+            for dim in sorted(self.dim, reverse=True):
+                input = torch.squeeze(input, dim=dim)
+            return input
